pub struct ContractCallLocalQuery {
pub header: Option<QueryHeader>,
pub contract_id: Option<ContractId>,
pub gas: i64,
pub function_parameters: Vec<u8>,
pub max_result_size: i64,
pub sender_id: Option<AccountId>,
}Expand description
Call a view function of a given smart contract
The call must provide function parameter inputs as needed.
This is potentially useful for calling view functions that will not revert
when executed in a static EVM context. Many such use cases will be better
served by using a Mirror Node API, however.
This is performed locally on the particular node that the client is
communicating with. Executing the call locally is faster and less costly,
but imposes certain restrictions.
The call MUST NOT change the state of the contract instance. This also
precludes any expenditure or transfer of HBAR or other tokens.
The call SHALL NOT have a separate consensus timestamp.
The call SHALL NOT generate a record nor a receipt.
The response SHALL contain the output returned by the function call.
Any contract call that would use the STATICCALL opcode MAY be called via
contract call local with performance and cost benefits.
Unlike a ContractCall transaction, the node SHALL always consume the entire amount of offered “gas” in determining the fee for this query, so accurate gas estimation is important.
Fields
header: Option<QueryHeader>Standard information sent with every query operation.
This includes the signed payment and what kind of response is requested
(cost, state proof, both, or neither).
The payment MUST be sufficient for the base fees _and_ the full amount in the `gas` field.
contract_id: Option<ContractId>The ID of a smart contract to call.
gas: i64The amount of “gas” to use for this call.
This transaction SHALL consume all of the gas offered and charge the corresponding fee according to the current exchange rate between HBAR and "gas".
function_parameters: Vec<u8>The smart contract function to call, and the parameters to pass to that function.
These SHALL be presented in EVM bytecode function call format.
max_result_size: i64Do not use this field; it is ignored in the current software.
The maximum number of bytes that the result might include.
The call will fail if it would have returned more than this number
of bytes.
sender_id: Option<AccountId>The account that is the “sender” for this contract call.
If this is not set it SHALL be interpreted as the accountId from the
associated transactionId.
If this is set then either the associated transaction or the foreign
transaction data MUST be signed by the referenced account.