pub struct QueryHeader {
pub payment: Option<Transaction>,
pub response_type: i32,
}Expand description
A standard query header.
Each query from the client to the node must contain a QueryHeader, which
specifies the desired response type, and includes a payment transaction
that will compensate the network for responding to the query.
The payment may be blank if the query is free.
The payment transaction MUST be a cryptoTransfer from the payer account
to the account of the node where the query is submitted.
If the payment is sufficient, the network SHALL respond with the response
type requested.
If the response type is COST_ANSWER the payment MUST be unset.
A state proof SHALL be available for some types of information.
A state proof SHALL be available for a Record, but not a receipt, and the
response entry for each supported “get info” query.
Fields
payment: Option<Transaction>A signed CryptoTransferTransaction to pay query fees.
This MUST transfer HBAR from the "payer" to the responding node account sufficient to pay the query fees.
response_type: i32A type of query response requested.
Implementations
Sourceimpl QueryHeader
impl QueryHeader
Sourcepub fn response_type(&self) -> ResponseType
pub fn response_type(&self) -> ResponseType
Returns the enum value of response_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_response_type(&mut self, value: ResponseType)
pub fn set_response_type(&mut self, value: ResponseType)
Sets response_type to the provided enum value.